@@ -19,15 +19,16 @@ def load(
     if dyne_names is None:
         dyne_names = []
     raw = hub.config.dirs.load(sources, dyne_names, cli)
-    os_vars = hub.config.os.init.gather(raw)
-    cli_args, raw_cli = hub.config.args.gather(raw, cli, parse_cli)
+    os_vars = hub.config.os_vars.gather(raw)
+    cli_args, raw_cli = hub.args.cli.gather(raw, cli, parse_cli)
     if cli_args.get("version"):
         hub.config.version.run(cli)
-    configs = hub.config.file.init.parse(raw, cli, os_vars, cli_args, loader)
+    configs = hub.config.file.parse(raw, cli, os_vars, cli_args, loader)
+
     opt = hub.config.order.apply(raw, raw_cli, cli, cli_args, os_vars, configs)
+    # Sync pop-config with the log-level
+    opt["pop_config"] = {k: opt[sources[0]][k] for k in opt["pop_config"]}
     hub.OPT = hub.pop.data.imap(opt)
 
     if logs:
-        authoritative_cli = hub.OPT[sources[0]]
-        log_plugin = authoritative_cli.get("log_plugin")
-        hub.log[log_plugin].setup(authoritative_cli)
+        hub.log[hub.OPT.pop_config.log_plugin].setup(hub.OPT.pop_config)
